#
# spec file for package cvsps
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cvsps
BuildRequires:  cmake
BuildRequires:  zlib-devel
Summary:        A Program for Generating Patch Set Information from a CVS Repository
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
# DO NOT UPGRADE to 3.x before you make sure it works with git-cvsps [bnc#809800]
Version:        2.1
Release:        184.3
%define real_version 2.1
Source:         cvsps-%{real_version}.tar.bz2
Source1:        bk-cvs.mail
Source2:        cvsps-bk-cvs.mail
Source3:        fixes.tar.bz2
Source4:        CMakeLists.txt
Obsoletes:      cvsps2 <= %{version}
Provides:       cvsps2 = %{version}
Patch0:         commitid.diff
URL:            http://www.cobite.com/cvsps/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
CVSps is a program for generating 'patchset' information from a CVS
repository. In this case, a patchset is defined as a set of changes
made to a collection of files, all committed at the same time (using a
single 'cvs commit' command). This information is valuable for seeing
the big picture of the evolution of a CVS project. While CVS tracks
revision information, it is often difficult to see what changes were
'atomically' committed to the repository.

%prep
%setup -q -n cvsps-%{real_version}
tar xvfj %{SOURCE3}
for patch in $(cat fixes/series); do
    patch -p1 < fixes/$patch
done
cp %{SOURCE1} %{SOURCE2} %{SOURCE4} .
%patch -P 0 -p1

%build
export CFLAGS="%{optflags}"
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} -DCMAKE_VERBOSE_MAKEFILE=TRUE .
%{__make} %{?jobs:-j%jobs}

%install
%makeinstall

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc README CHANGELOG COPYING
%doc bk-cvs.mail cvsps-bk-cvs.mail
%{_bindir}/cvsps
%{_mandir}/man*/*

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Tue May  7 2013 pgajdos@suse.com
- downgrade to 2.1 [bnc#809800]
* Wed Apr 24 2013 pgajdos@suse.com
- conflicts with cvsps2 [bnc#809800]
* Tue Jan 29 2013 pgajdos@suse.com
- update to 3.10
  * Make the behavior of a second -d option match the documentation.
* Mon Jan 21 2013 pgajdos@suse.com
- update to 3.9
  * Added -i option for generating incremental fast exports.
* Tue Jan 15 2013 mvyskocil@suse.com
- update to 3.8
  * fix buggy generation of the revision-map file (thanks to Chris Rorvick).
  * don't convert .cvsignores by default, we have field reports of collisions.
* Fri Jan 11 2013 mvyskocil@suse.com
- update to 3.7
  * bug fix in timezone handling (thanks to Chris Rorvick).
  * major performance gain in the CVS client code (thanks to
    Sergei Trofimovich).
  * third field in an author entry is now interpreted as if it
    were TZ.
  * remove the --test-log option now that cvsps has its own test suite.
  * new --reposurgeon option for passing reference-lifting hints
    to reposurgeon.
* Wed Jan  2 2013 mvyskocil@suse.com
- update to 3.4 with fast-export dumping
  * maintained by Eric S. Raymond
  * more focused on --fast-export mode only
  * now always runs in what used to be csv_direct mode
  * it's not required to run csvps in CVS checkout directory
  * local cvs commands are no longer used
  * the old-style non-fast-export reporting mode is deprecated and
    may be dropped in the future
  * removed the --bkcvs and -x options
  * new --fast-export option allows dumping the history as a git
    import stream
  * the -A now works in the expected way
  * add -R option that writes out a revision map
  * incorporates Heiko Voight's patch for solving some time-skew cases
  * check README and NEWS for details
- obsoleted files and patches
  * bk-cvs.mail - who is interested in BitKeeper/CSV kernel trees?
  * cvsps-bk-cvs.mail - or the ability to import BitKeeper logs?
  * fixes.tar.bz2 - they are upstream
  * CMakeLists.txt - plain make is recommended
  * commitid.diff - already upstream
* Wed Sep  3 2008 schwab@suse.de
- Fix broken cmakefile.
- Add support for commitid.
* Tue Nov  6 2007 crrodriguez@suse.de
- instead of patching the Makefiles use a simple cmake based build script
* Tue Jul 31 2007 agruen@suse.de
- Add fixes from http://ydirson.free.fr/soft/git/cvsps.git.
- Use RPM_OPT_FLAGS.
* Fri Mar 30 2007 ro@suse.de
- added zlib-devel to buildreq
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct  5 2005 dmueller@suse.de
- add norootforbuild
* Mon May 30 2005 agruen@suse.de
- Updater to version 2.1.
* Mon May  5 2003 agruen@suse.de
- Update to version 2.0rc1.
* Thu Mar 20 2003 agruen@suse.de
- Initial package.
